<?PHP
/**
 * Represents a possible target for importing related works
 * as defined by LIDO.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Represents a possible target for importing related works
 * as defined by LIDO.
 */
enum MDConcFieldRelatedWorksType {

    case related_works_freetext;
    case series;
    case literature;
    case weblink;
    case undefined;

    /**
     * Returns a target field value of this type based on a string.
     *
     * @param string $input Input to get a value from.
     *
     * @return MDConcFieldRelatedWorksType
     */
    public static function fromString(string $input):MDConcFieldRelatedWorksType {

        return match($input) {

            "Dokumentiert in",
            "dokumentiert in",
            'is documented in',
            "Erwähnung in",
            ":iterature",
            "Beschrieben in",
            "Literatur",
            "Literatur in Zusammenhang",
            'Literatur zum Stück',
            'Standardzitierwerk',
            "wird beschrieben in",
            'http://digicult.vocnet.org/terminology/ter01113',
            'http://terminology.lido-schema.org/lido00617',
            'Quelle',
            "beschrieben in" => self::literature,

            "Teil von",
            "ist Teil von",
            "Gehört zu",
            "gehört zu",
            "Gehört zu Sammlung",
            "gehört zu Sammlung",
            "Part of",
            "Gesamtwerk",
            "part of",
            "Photoserie",
            "Mappe",
            "series",
            "Konvolut",
            "http://digicult.vocnet.org/terminology/ter00235",
            "Serie" => self::series,

            "hat Vorlage",
            "Kopie von",
            "Objekt",
            "ist Version von",
            "inhaltlicher Bezug zu",
            "Teil",
            "Teil 1",
            "Teil 2",
            "Teil 3",
            "Teil 4",
            "hat Teil",
            "has part",
            "Dublette",
            "Objektbezug",
            "Vergleiche",
            "Umfasst",
            "Entwurf",
            "Vorderseite",
            "Rückseite",
            "Paarweise mit",
            "Zustandsdruck",
            "Foto",
            "Original",
            "Variante",
            "Aufnahme Objekt",
            "Zusammen mit",
            "Ausführung",
            "Related objects",
            "Abbildung identisch",
            'http://digicult.vocnet.org/terminology/ter00223',
            "Join",
            "Hauptobjekt",
            "Akte",
            "Vorgang",
            "Form",
            "Identisch mit",
            "Kopie",
            "Gegenstück zu",
            "hat Version",
            "hat Kopie",
            "ist Verso von",
            "ist Recto von",
            "ist Kopie nach",
            "ist Quelle für",
            "in Beziehung zu",
            "ist abgeleitet von",
            "ist vorbereitend für",
            "Enthalten in",
            "Enthält",
            "Verso von",
            "Recto von",
            "ist Teil desselben konzeptuellen Ganzen mit",
            "ist vorbereitende Studie für",
            "Druck",
            "Referenz",
            "Haupttafel",
            "Faksimile",
            "Blatt",
            "Photo",
            "Einzelteil",
            'Objekt identisch',
            'Form von',
            'Formprodukt von',
            'Abbildung weitgehend identisch',
            'abgebildet auf/in',
            'bildet ab',
            'Pendant zu',
            'enthält',
            'hat Bezug zu',
            'http://terminology.lido-schema.org/lido00263',
            'http://digicult.vocnet.org/terminology/ter00224',
            'http://digicult.vocnet.org/terminology/ter00225',
            'http://digicult.vocnet.org/terminology/ter00230',
            'http://digicult.vocnet.org/terminology/ter00231',
            'http://digicult.vocnet.org/terminology/ter00233',
            'http://digicult.vocnet.org/terminology/ter00234',
            'http://digicult.vocnet.org/terminology/ter00243',
            'http://digicult.vocnet.org/terminology/ter00238',
            'http://digicult.vocnet.org/terminology/ter01237',
            "verwandt mit",
            "Zusammen ein Ganzes bildend mit",
            "Vorlage" => self::related_works_freetext,

            "Weblink",
            "Web link",
            "Fachportal",
            'Externer Link',
            'http://digicult.vocnet.org/terminology/ter01391'
            => self::weblink,

            "" => self::undefined,

            default => throw new MDpageParameterNotFromListException("Unknown target field for related works type: " . $input),
        };

    }
}
